<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>Verificarea aplicației de transfer va instala automat versiunea corespunzătoare a aplicației UOS.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Confirmați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anulați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>Aplicație</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>Recomandare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>Transferabilă</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>Necorespunzătoare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>Selectați aplicațiile de transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>Vă rugăm să selectați aplicațiile pentru backup</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>Transferul datelor UOS</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>Uitool de transfer UOS permite migrarea într-o singură clic a fișierelor, datelor personale și a aplicațiilor către UOS, vă ajutând să înlocuiți ușor sistemul dvs.</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>Exportați în directorul local</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>Selectați un mod de transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>Nu se poate conecta la rețea, vă rugăm să verificați conexiunea la rețea sau să selectați export în directorul local.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>De la un computer Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>Importați din fișierele de backup</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>Verificarea configurării de transfer va aplica automat configurarea la UOS.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Confirmați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Anulați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>Bookmarkurile navigatorului</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>Recomandare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>Transferabilă</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>Setări personale</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>Fundal personalizat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>Selectați configurarea de transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>Vă rugăm să selectați configurările pentru backup</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>Gata de conectare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>Vă rugăm să deschideți transferul datelor pe Windows și să introduceți codul IP și codul de conectare.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>Descărcați clientul Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>Codul de conectare a expirat, vă rugăm să refrescați pentru un cod nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>computer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>Actualizează</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>Codul va expira în</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>vă rugăm să introduceți codul de conectare cât mai repede posibil</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>Creează o copie de date</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>Informații despre fișier</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>mărime:0B</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>Locație</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(Selectați discul de backup)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>Spațiul disponibil în discul selectat este insuficient, vă rugăm să curățați spațiul</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>Backup</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>Mărime:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>disc local</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 disponibil&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>Reselectați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>Continuați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>&gt;-
 A fost detectată prezența unor sarcini de transfer neîncheiate între dumneavoastră și dispozitivul țintă.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>Doriți să continuați cu ultimul transfer?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>Transferul va fi finalizat în</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>Încercați din nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>Eroare de rețea</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>Transferul a fost întrerupt</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>&gt;-
 Rețeaua s-a dezconectat, transferul a eșuat, vă rugăm să conectați rețeaua și încercați din nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>Spațiul disponibil în UOS este insuficient, vă rugăm să curățați cel puțin %1 GB și încercați din nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>Spațiul este insuficient în UOS, vă rugăm să curățați cel puțin %1 GB și să încercați din nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>Spațiul este insuficient în UOS, vă rugăm să rezervați suficient spațiu</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>După finalizarea transferului, datele vor fi plasate în directorul utilizatorului</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>Confirmați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Anulați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>Selectați fișierul de transferat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>Vă rugăm să selectați fișierele pentru backup</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>Rețeaua a fost dezconectată. Vă rugăm să verificați rețeaua</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>Încercați din nou</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>Instalare</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>Înainte de transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>Transferul datelor necesită timp, pentru a evita întreruperile migrației din cauza bateriei slabe, vă rugăm să rămâneți conectat la curent.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>Alte aplicații pot reduce viteza transferului. Pentru o experiență mai fluidă, vă rugăm să închideți alte aplicații.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>Pentru securitatea transferului, vă rugăm să folosiți o rețea de încredere.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>Confirmați</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>Gata de conectare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>Vă rugăm să introduceți IP-ul UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>Vă rugăm să activați transferul datelor pe UOS și să obțineți IP-ul</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>Cod de conectare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>Vă rugăm să introduceți codul de conectare pe UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>conectare…</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>Eroare la conectare, vă rugăm să verificați intrarea</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>Transferul a fost completat parțial</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>Transferul a fost completat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>Migrația parțială a informațiilor a eșuat, vă rugăm să mergeți la UOS pentru transfer manual</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>Ieșire</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>Selectat:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>Selectat:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>Editează</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>Fișier</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>Aplicație</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>Configurare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>Selectați datele pentru transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>Vă rugăm să selectați conținutul pentru backup</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>Începe transferul</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>Profile</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>Profil incorect sau lipsă</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>Fundalul meu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>Transferul a fost finalizat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>Marcajele browserului</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>BrowserBookMark</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>este instalat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>Se instalează</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>Transferul a eșuat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>Eroare de format</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>Configurarea a eșuat, configurarea poate fi importată manual</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>Instalarea a eșuat, vă rugăm să mergeți la magazinul de aplicații pentru instalare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>Transfer Finalizat</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>Imagini</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>Selectează:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>discul local</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>Transfer de date UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>UOS transfer tool permite migrarea într-o singură click a fișierelor, datelor personale și aplicațiilor tale către UOS, te ajutând să înlocuiesti în mod fluid sistemul tău.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>Transfer</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>Se transferă...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>Se calculează...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>Arată procese</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>Ascunde procese</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Transferul va fi finalizat în %1 minute</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>Transfer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Transferul va fi finalizat în %1 secunde</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>Transferul va fi finalizat în --</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>Dezarhivare</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>Dezarhivare</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>Trage fișierul aici </translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>Importă fișier</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>Doar fișierele .zip sunt acceptate, vă rugăm să</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>reselectați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>selectați un fișier zip</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>Fișier ZIP (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>Selectați fișierul de transfer de date</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>Eroare de fișier, transferul nu poate fi realizat, vă rugăm să reselectați</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>Încearcă din nou</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>Fișierul este corupt și nu poate fi migrat. Vă rugăm să îl înlocuiți cu un fișier de backup.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>Spațiu insuficient pe UOS. Vă rugăm să rezervați cel puțin %1G de spațiu și încercați din nou.</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>Calculare</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>Așteptare transfer...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>Vă rugăm să selectați datele de transfer pe Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>Această operație va șterge progresul de transfer. Doriți să continuați?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>Această operație nu este reversibilă</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>Backup reușit</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>Felicitări, informațiile tale au fost cu succes salvate în backup.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>Mergi la vizualizare</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>Backup eșuat</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>Pachetare %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Transferul se va finaliza în %1 minute</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Transferul se va finaliza în %1 secunde</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>Se creează fișierul de backup...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 Comprimare fișier eșuată&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>Backup fișier finalizat</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>Transfer de date UOS</translation>
    </message>
</context>
</TS>